@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: attoparsec
-version: 0.10.1.0
-id: attoparsec-0.10.1.0-fbbd15f07775c506a88ff9688f1e3d80
+version: 0.10.4.0
+id: attoparsec-0.10.4.0-d9fd97cfc1a1748b3cde35adf7fd233b
 
 license: BSD3
 copyright:
@@ -9,6 +9,7 @@ maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
 stability: experimental
 homepage: https://github.com/bos/attoparsec
 package-url:
+synopsis: Fast combinator parsing for bytestrings and text
 description: A fast parser combinator library, aimed particularly at dealing
              efficiently with network protocols and complicated text/binary
              file formats.
@@ -23,26 +24,28 @@ exposed-modules: Data.Attoparsec Data.Attoparsec.ByteString
                  Data.Attoparsec.Text.Lazy Data.Attoparsec.Types
                  Data.Attoparsec.Zepto
 hidden-modules: Data.Attoparsec.ByteString.FastSet
-                Data.Attoparsec.ByteString.Internal Data.Attoparsec.Internal.Types
-                Data.Attoparsec.Text.FastSet Data.Attoparsec.Text.Internal
-import-dirs: /usr/local/lib/ghc/attoparsec-0.10.1.0
-library-dirs: /usr/local/lib/ghc/attoparsec-0.10.1.0
-hs-libraries: HSattoparsec-0.10.1.0
+                Data.Attoparsec.ByteString.Internal Data.Attoparsec.Internal
+                Data.Attoparsec.Internal.Types Data.Attoparsec.Text.FastSet
+                Data.Attoparsec.Text.Internal
+trusted: False
+import-dirs: /usr/local/lib/ghc/attoparsec-0.10.4.0
+library-dirs: /usr/local/lib/ghc/attoparsec-0.10.4.0
+hs-libraries: HSattoparsec-0.10.4.0
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: array-0.3.0.2-f538acad67d0b6696484da310d5949cf
-         base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
-         bytestring-0.9.1.10-4e62762ee9b2a5d0cc5bc2fbaaeefd53
-         containers-0.4.0.0-f1307d32d8f4b51a1487c01f0997b6d9
-         deepseq-1.1.0.2-ce16381c4a634f8997917e5081cb960a
-         text-0.11.1.5-a9f0a532672121c1439a824b6891e297
+depends: array-0.4.0.1-3b78425c10ff2dad7acf7e8c8ae014c3
+         base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
+         bytestring-0.10.0.2-1c6ab0cabcb254a0e55d751d8ef17b51
+         containers-0.5.0.0-ab1dae9a94cd3cc84e7b2805636ebfa2
+         deepseq-1.3.0.1-5cc4cd89bdc2e8f6db1833d95ec36926
+         text-0.11.3.1-5af30448b2c3a30eee31b3ea9b549812
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-attoparsec-0.10.1.0/html/attoparsec.haddock
-haddock-html: /usr/local/share/doc/hs-attoparsec-0.10.1.0/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-attoparsec-0.10.4.0/html/attoparsec.haddock
+haddock-html: /usr/local/share/doc/hs-attoparsec-0.10.4.0/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
